==> instrumentation-2.2.0-sources.jar: cloud/filibuster/examples/UserServiceGrpc.java <==
package cloud.filibuster.examples;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.36.1)",
    comments = "Source: hello.proto")
public final class UserServiceGrpc {

  private UserServiceGrpc() {}

  public static final String SERVICE_NAME = "cloud.filibuster.examples.UserService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.ValidateSessionRequest,
      cloud.filibuster.examples.Hello.ValidateSessionResponse> getValidateSessionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "ValidateSession",
      requestType = cloud.filibuster.examples.Hello.ValidateSessionRequest.class,
      responseType = cloud.filibuster.examples.Hello.ValidateSessionResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.ValidateSessionRequest,
      cloud.filibuster.examples.Hello.ValidateSessionResponse> getValidateSessionMethod() {
    io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.ValidateSessionRequest, cloud.filibuster.examples.Hello.ValidateSessionResponse> getValidateSessionMethod;
    if ((getValidateSessionMethod = UserServiceGrpc.getValidateSessionMethod) == null) {
      synchronized (UserServiceGrpc.class) {
        if ((getValidateSessionMethod = UserServiceGrpc.getValidateSessionMethod) == null) {
          UserServiceGrpc.getValidateSessionMethod = getValidateSessionMethod =
              io.grpc.MethodDescriptor.<cloud.filibuster.examples.Hello.ValidateSessionRequest, cloud.filibuster.examples.Hello.ValidateSessionResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "ValidateSession"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.ValidateSessionRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.ValidateSessionResponse.getDefaultInstance()))
              .setSchemaDescriptor(new UserServiceMethodDescriptorSupplier("ValidateSession"))
              .build();
        }
      }
    }
    return getValidateSessionMethod;
  }

  private static volatile io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.GetUserRequest,
      cloud.filibuster.examples.Hello.GetUserResponse> getGetUserFromSessionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetUserFromSession",
      requestType = cloud.filibuster.examples.Hello.GetUserRequest.class,
      responseType = cloud.filibuster.examples.Hello.GetUserResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.GetUserRequest,
      cloud.filibuster.examples.Hello.GetUserResponse> getGetUserFromSessionMethod() {
    io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.GetUserRequest, cloud.filibuster.examples.Hello.GetUserResponse> getGetUserFromSessionMethod;
    if ((getGetUserFromSessionMethod = UserServiceGrpc.getGetUserFromSessionMethod) == null) {
      synchronized (UserServiceGrpc.class) {
        if ((getGetUserFromSessionMethod = UserServiceGrpc.getGetUserFromSessionMethod) == null) {
          UserServiceGrpc.getGetUserFromSessionMethod = getGetUserFromSessionMethod =
              io.grpc.MethodDescriptor.<cloud.filibuster.examples.Hello.GetUserRequest, cloud.filibuster.examples.Hello.GetUserResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetUserFromSession"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.GetUserRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.GetUserResponse.getDefaultInstance()))
              .setSchemaDescriptor(new UserServiceMethodDescriptorSupplier("GetUserFromSession"))
              .build();
        }
      }
    }
    return getGetUserFromSessionMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static UserServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UserServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UserServiceStub>() {
        @java.lang.Override
        public UserServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UserServiceStub(channel, callOptions);
        }
      };
    return UserServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static UserServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UserServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UserServiceBlockingStub>() {
        @java.lang.Override
        public UserServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UserServiceBlockingStub(channel, callOptions);
        }
      };
    return UserServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static UserServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UserServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UserServiceFutureStub>() {
        @java.lang.Override
        public UserServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UserServiceFutureStub(channel, callOptions);
        }
      };
    return UserServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class UserServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void validateSession(cloud.filibuster.examples.Hello.ValidateSessionRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.ValidateSessionResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getValidateSessionMethod(), responseObserver);
    }

    /**
     */
    public void getUserFromSession(cloud.filibuster.examples.Hello.GetUserRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.GetUserResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetUserFromSessionMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getValidateSessionMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                cloud.filibuster.examples.Hello.ValidateSessionRequest,
                cloud.filibuster.examples.Hello.ValidateSessionResponse>(
                  this, METHODID_VALIDATE_SESSION)))
          .addMethod(
            getGetUserFromSessionMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                cloud.filibuster.examples.Hello.GetUserRequest,
                cloud.filibuster.examples.Hello.GetUserResponse>(
                  this, METHODID_GET_USER_FROM_SESSION)))
          .build();
    }
  }

  /**
   */
  public static final class UserServiceStub extends io.grpc.stub.AbstractAsyncStub<UserServiceStub> {
    private UserServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UserServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UserServiceStub(channel, callOptions);
    }

    /**
     */
    public void validateSession(cloud.filibuster.examples.Hello.ValidateSessionRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.ValidateSessionResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getValidateSessionMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void getUserFromSession(cloud.filibuster.examples.Hello.GetUserRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.GetUserResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetUserFromSessionMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class UserServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<UserServiceBlockingStub> {
    private UserServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UserServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UserServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public cloud.filibuster.examples.Hello.ValidateSessionResponse validateSession(cloud.filibuster.examples.Hello.ValidateSessionRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getValidateSessionMethod(), getCallOptions(), request);
    }

    /**
     */
    public cloud.filibuster.examples.Hello.GetUserResponse getUserFromSession(cloud.filibuster.examples.Hello.GetUserRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetUserFromSessionMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class UserServiceFutureStub extends io.grpc.stub.AbstractFutureStub<UserServiceFutureStub> {
    private UserServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UserServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UserServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.filibuster.examples.Hello.ValidateSessionResponse> validateSession(
        cloud.filibuster.examples.Hello.ValidateSessionRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getValidateSessionMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.filibuster.examples.Hello.GetUserResponse> getUserFromSession(
        cloud.filibuster.examples.Hello.GetUserRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetUserFromSessionMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_VALIDATE_SESSION = 0;
  private static final int METHODID_GET_USER_FROM_SESSION = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final UserServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(UserServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_VALIDATE_SESSION:
          serviceImpl.validateSession((cloud.filibuster.examples.Hello.ValidateSessionRequest) request,
              (io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.ValidateSessionResponse>) responseObserver);
          break;
        case METHODID_GET_USER_FROM_SESSION:
          serviceImpl.getUserFromSession((cloud.filibuster.examples.Hello.GetUserRequest) request,
              (io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.GetUserResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class UserServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    UserServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return cloud.filibuster.examples.Hello.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("UserService");
    }
  }

  private static final class UserServiceFileDescriptorSupplier
      extends UserServiceBaseDescriptorSupplier {
    UserServiceFileDescriptorSupplier() {}
  }

  private static final class UserServiceMethodDescriptorSupplier
      extends UserServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    UserServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (UserServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new UserServiceFileDescriptorSupplier())
              .addMethod(getValidateSessionMethod())
              .addMethod(getGetUserFromSessionMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> instrumentation-3.0.0-sources.jar: cloud/filibuster/examples/UserServiceGrpc.java <==
package cloud.filibuster.examples;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.36.1)",
    comments = "Source: hello.proto")
public final class UserServiceGrpc {

  private UserServiceGrpc() {}

  public static final String SERVICE_NAME = "cloud.filibuster.examples.UserService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.ValidateSessionRequest,
      cloud.filibuster.examples.Hello.ValidateSessionResponse> getValidateSessionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "ValidateSession",
      requestType = cloud.filibuster.examples.Hello.ValidateSessionRequest.class,
      responseType = cloud.filibuster.examples.Hello.ValidateSessionResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.ValidateSessionRequest,
      cloud.filibuster.examples.Hello.ValidateSessionResponse> getValidateSessionMethod() {
    io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.ValidateSessionRequest, cloud.filibuster.examples.Hello.ValidateSessionResponse> getValidateSessionMethod;
    if ((getValidateSessionMethod = UserServiceGrpc.getValidateSessionMethod) == null) {
      synchronized (UserServiceGrpc.class) {
        if ((getValidateSessionMethod = UserServiceGrpc.getValidateSessionMethod) == null) {
          UserServiceGrpc.getValidateSessionMethod = getValidateSessionMethod =
              io.grpc.MethodDescriptor.<cloud.filibuster.examples.Hello.ValidateSessionRequest, cloud.filibuster.examples.Hello.ValidateSessionResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "ValidateSession"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.ValidateSessionRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.ValidateSessionResponse.getDefaultInstance()))
              .setSchemaDescriptor(new UserServiceMethodDescriptorSupplier("ValidateSession"))
              .build();
        }
      }
    }
    return getValidateSessionMethod;
  }

  private static volatile io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.GetUserRequest,
      cloud.filibuster.examples.Hello.GetUserResponse> getGetUserMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetUser",
      requestType = cloud.filibuster.examples.Hello.GetUserRequest.class,
      responseType = cloud.filibuster.examples.Hello.GetUserResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.GetUserRequest,
      cloud.filibuster.examples.Hello.GetUserResponse> getGetUserMethod() {
    io.grpc.MethodDescriptor<cloud.filibuster.examples.Hello.GetUserRequest, cloud.filibuster.examples.Hello.GetUserResponse> getGetUserMethod;
    if ((getGetUserMethod = UserServiceGrpc.getGetUserMethod) == null) {
      synchronized (UserServiceGrpc.class) {
        if ((getGetUserMethod = UserServiceGrpc.getGetUserMethod) == null) {
          UserServiceGrpc.getGetUserMethod = getGetUserMethod =
              io.grpc.MethodDescriptor.<cloud.filibuster.examples.Hello.GetUserRequest, cloud.filibuster.examples.Hello.GetUserResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetUser"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.GetUserRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.filibuster.examples.Hello.GetUserResponse.getDefaultInstance()))
              .setSchemaDescriptor(new UserServiceMethodDescriptorSupplier("GetUser"))
              .build();
        }
      }
    }
    return getGetUserMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static UserServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UserServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UserServiceStub>() {
        @java.lang.Override
        public UserServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UserServiceStub(channel, callOptions);
        }
      };
    return UserServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static UserServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UserServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UserServiceBlockingStub>() {
        @java.lang.Override
        public UserServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UserServiceBlockingStub(channel, callOptions);
        }
      };
    return UserServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static UserServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<UserServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<UserServiceFutureStub>() {
        @java.lang.Override
        public UserServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new UserServiceFutureStub(channel, callOptions);
        }
      };
    return UserServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class UserServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void validateSession(cloud.filibuster.examples.Hello.ValidateSessionRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.ValidateSessionResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getValidateSessionMethod(), responseObserver);
    }

    /**
     */
    public void getUser(cloud.filibuster.examples.Hello.GetUserRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.GetUserResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetUserMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getValidateSessionMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                cloud.filibuster.examples.Hello.ValidateSessionRequest,
                cloud.filibuster.examples.Hello.ValidateSessionResponse>(
                  this, METHODID_VALIDATE_SESSION)))
          .addMethod(
            getGetUserMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                cloud.filibuster.examples.Hello.GetUserRequest,
                cloud.filibuster.examples.Hello.GetUserResponse>(
                  this, METHODID_GET_USER)))
          .build();
    }
  }

  /**
   */
  public static final class UserServiceStub extends io.grpc.stub.AbstractAsyncStub<UserServiceStub> {
    private UserServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UserServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UserServiceStub(channel, callOptions);
    }

    /**
     */
    public void validateSession(cloud.filibuster.examples.Hello.ValidateSessionRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.ValidateSessionResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getValidateSessionMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void getUser(cloud.filibuster.examples.Hello.GetUserRequest request,
        io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.GetUserResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetUserMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class UserServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<UserServiceBlockingStub> {
    private UserServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UserServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UserServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public cloud.filibuster.examples.Hello.ValidateSessionResponse validateSession(cloud.filibuster.examples.Hello.ValidateSessionRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getValidateSessionMethod(), getCallOptions(), request);
    }

    /**
     */
    public cloud.filibuster.examples.Hello.GetUserResponse getUser(cloud.filibuster.examples.Hello.GetUserRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetUserMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class UserServiceFutureStub extends io.grpc.stub.AbstractFutureStub<UserServiceFutureStub> {
    private UserServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected UserServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new UserServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.filibuster.examples.Hello.ValidateSessionResponse> validateSession(
        cloud.filibuster.examples.Hello.ValidateSessionRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getValidateSessionMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.filibuster.examples.Hello.GetUserResponse> getUser(
        cloud.filibuster.examples.Hello.GetUserRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetUserMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_VALIDATE_SESSION = 0;
  private static final int METHODID_GET_USER = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final UserServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(UserServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_VALIDATE_SESSION:
          serviceImpl.validateSession((cloud.filibuster.examples.Hello.ValidateSessionRequest) request,
              (io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.ValidateSessionResponse>) responseObserver);
          break;
        case METHODID_GET_USER:
          serviceImpl.getUser((cloud.filibuster.examples.Hello.GetUserRequest) request,
              (io.grpc.stub.StreamObserver<cloud.filibuster.examples.Hello.GetUserResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class UserServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    UserServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return cloud.filibuster.examples.Hello.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("UserService");
    }
  }

  private static final class UserServiceFileDescriptorSupplier
      extends UserServiceBaseDescriptorSupplier {
    UserServiceFileDescriptorSupplier() {}
  }

  private static final class UserServiceMethodDescriptorSupplier
      extends UserServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    UserServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (UserServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new UserServiceFileDescriptorSupplier())
              .addMethod(getValidateSessionMethod())
              .addMethod(getGetUserMethod())
              .build();
        }
      }
    }
    return result;
  }
}
